--
-- Simple test of iodbc binding
--
-- Sune Falck 2000-02-05
--
-- Usage:
--    Create test table iodbctest and run the program as
--    test_iodbc dsn user password
--
-- $Revision: 1.1 $              $Date: 2000/02/05 19:41:34 $
--

with Ada.Text_IO;      use Ada.Text_IO;
with Ada.Command_Line; use Ada.Command_Line;
with Interfaces.C;     use Interfaces.C;
with Iodbc;            use Iodbc;

procedure Test_Iodbc is

   Env   : aliased SQLHENV;
   Dbc   : aliased SQLHDBC;
   Stmt  : aliased SQLHSTMT;

   Num  : aliased Integer;
   Text : String (1..17);      -- One more than the field size
   Sts  : Retcode;

   Null_Value  : aliased SDWORD;
   Text_Length : aliased SDWORD;

   Sql_Error : exception;
   Command_Syntax_Error : exception;

   procedure Error (Sts: Retcode; Text : String) is
   begin
      if Sts /= Sql_Success then
         Put_Line ("Error " & retcode'image(sts) & " in " & Text);
         raise Sql_Error;
      end if;
   end Error;

begin
   if Argument_Count /= 3 then
      Put_Line ("syntax: iodbc_test dsn user password");
      raise Command_Syntax_Error;
   end if;
   --
   -- Allocate odbc environment resouces
   --
   Sts := SqlAllocEnv (Env'Unchecked_Access);
   Error (Sts, "allocenv");
   --
   -- Connect
   --
   Sts := SqlAllocConnect (Env, Dbc'Unchecked_Access);
   Error (Sts, "allocdbc");

   Sts := SQLConnect (Dbc, To_C (Argument (1)), Argument (1)'Length,
                           To_C (Argument (2)), Argument (2)'Length,
                           To_C (Argument (3)), Argument (3)'Length);
   Error (Sts, "connect");
   --
   -- Prepare a statement for execution and bind output fields to program
   -- variables
   --
   Sts := SqlAllocStmt (Dbc, Stmt'Unchecked_Access);
   Error (Sts, "allocstmt");

   Sts := SqlPrepare (Stmt, To_C ("SELECT NUM, TEXT FROM IODBCTEST"), SQL_NTS);
   Error (Sts, "prepare");

   Sts := SqlBindCol (Stmt, 1, Sql_Integer, Num'Address,
                      0, Null_Value'Unchecked_Access);
   Error (Sts, "bind num");

   Sts := SqlBindCol (Stmt, 2, Sql_Char, Text'Address,
                      Text'Length, Text_Length'Unchecked_Access);
   Error (Sts, "bind text");
   --
   -- Execute the statement to get a result set
   --
   Sts := SqlExecute (Stmt);
   Error (Sts, "execute");
   --
   -- Fetch rows from the result set and print length of returned text
   -- Fetch returns a terminating zero for char fields which must be
   -- taken care of.
   --
   loop
      Sts :=  Sqlfetch (Stmt);
      exit when Sts /= Sql_Success;

      Put_Line (Integer'Image (Num) & " - " & Text (1 .. 16) &
                " (" & sdword'image(Text_Length) & ")");
   end loop;
   Put_Line ("Fetch = " & Retcode'Image (Sts));
   --
   -- Release resources and drop conection
   --
   Sts := SQLFreeStmt (stmt, SQL_DROP);
   Error (Sts, "freestmt");
   Sts := SQLDisconnect (dbc);
   Error (Sts, "disconnect");
   Sts := SQLFreeConnect (dbc);
   Error (Sts, "freeconect");
   Sts := SQLFreeEnv (env);
   Error (Sts, "freeenv");

end Test_Iodbc;
